#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from .interfaces import IImagePortletConfiguration
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_PERMISSION

# import packages
from pyams_file.property import FileProperty
from pyams_portal.portlet import portlet_config, Portlet, PortletConfiguration, PortletRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from zope.interface import implementer, Interface

from pyams_portal import _


IMAGE_PORTLET_NAME = 'pyams_portal.portlet.image'


@portlet_config(permission=VIEW_PERMISSION)
class ImagePortlet(Portlet):
    """Image portlet

    The goal of this portlet is to display an image
    """

    name = IMAGE_PORTLET_NAME
    label = _("Image")

    toolbar_image = None
    toolbar_css_class = 'fa fa-fw fa-2x fa-picture-o'


@adapter_config(context=ImagePortlet, provides=IImagePortletConfiguration)
@implementer(IImagePortletConfiguration)
class ImagePortletConfiguration(PortletConfiguration):
    """Image portlet configuration"""

    image = FileProperty(IImagePortletConfiguration['image'])


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, ImagePortlet), provides=IPortletRenderer)
@template_config(template='image.pt', layer=IPyAMSLayer)
class ImagePortletRenderer(PortletRenderer):
    """Image portlet renderer"""
